<?PHP
/*
Plugin Name: Auto Post Images (API)
Plugin URI: http://www.karthikeyankarunanidhi.com
Version: 2.2
Author: <a href="http://www.karthikeyankarunanidhi.com">Karthikeyan Karunanidhi</a>
Description: Automatically adds images to posts without having to edit the post.

Copyright Karthikeyan Karunanidhi (email : wordpress [a t ] karunanidhi DOT com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

	if (!class_exists("KKAutoPostImages")) {

		require_once (dirname(__FILE__) . '/php/Filesystem.class.php');
		require_once (dirname(__FILE__) . '/php/ThumbCreator.class.php');

		/**
		* Auto Post Images (API) class
		*
		* Methods and variables for the Auto Post Images (API) plugin. Inserts images automatically into blog posts based on their POSTID
		*
		* @author Karthikeyan Karunanidhi <wordpress@karunanidhi.com>
		* @access public
		* @copyright GNU General Public License.
		* @package com.karunanidhi.karthikeyan
		*/
		class KKAutoPostImages {

			/**
			* The ID of the blog post. Set to $post->ID using global $post
			*/
			var $iPostId = FALSE;

			/**
			* The directory path to the images folder. Make sure you put the plugin files in /wp-content/plugins/auto-post-images-api/
			*/
			var $sImageDirPath = '';

			/**
			* The directory path to the images folder. Make sure you put the plugin files in /wp-content/plugins/auto-post-images-api/
			*/
			var $sImageThumbnailDirPath = '';

			/**
			* The directory path to the images folder. Make sure you put the plugin files in /wp-content/plugins/auto-post-images-api/
			*/
			var $sImageCacheDir = '';

			/**
			* The URL to the images folder. Make sure you put the plugin files in /wp-content/plugins/auto-post-images-api/
			*/
			var $sImageDirUrl = '';

			/**
			* The URL to the thumbnail images folder. Make sure you put the plugin files in /wp-content/plugins/auto-post-images-api/
			*/
			var $sImageThumbnailDirUrl = '';

			/**
			* The name of the default image that is displayed on a blog post when images are not found for that blog post
			*/
			var $sDefaultImageName = 'imagecomingsoon.jpg';

			/**
			* The URL of the default image that is displayed on a blog post when images are not found for that blog post
			*/
			var $sDefaultImageUrl = '';

			/**
			* Unique name to use for the plugin settings screen
			*/
			var $sAdminOptionsName = 'KK_API_ADMIN_OPTIONS';

			/**
			* Plugin settings
			*/
			var $aAdminOptions = array (
											"bDisplayDefaultImage" => 'YES',
											"bUseThumbnails" => 'YES',
											"sImageDirPath" => '',
											"sImageThumbnailDirPath" => '',
											"sImageDirUrl" => '',
											"sImageThumbnailDirUrl" => '',
											"sImageCacheDir" => '',
											"sRegEx" => "^Image___POSTID__[^0-9]*\.[a-zA-Z]+$",
											"bOptmizeImagesForSearch" => 'NO'
										);
			/**
			* Regular expression to use when searching for images associated with a post.
			* Must have __POSTID__ somewhere in the expression which will be replaced with
			*  the postid before searching for images
			*/
			var $sRegEx = "^Image___POSTID__[^0-9]*\.[a-zA-Z]+$";

			/**
			* Default regular expression to use when searching for images associated with a post.
			*/
			var $sDefaultRegEx = "^Image___POSTID__[^0-9]*\.[a-zA-Z]+$";

			/**
			* Default regular expression to use when renaming images for SEO
			*/
			var $sImageSEOPrefix = "api";
			var $sImageSEOPattern = '';

			/**
			* Constructor. Calls the init method
			*/
			function KKAutoPostImages () {

				$this->sImageSEOPattern = '^' . $this->sImageSEOPrefix . '[0-9]+_';

				$this->init();

				//echo '<pre>'.print_r($this->aAdminOptions, TRUE).'</pre>';

				$this->sImageDirPath = ( empty($this->aAdminOptions['sImageDirPath']) || !is_dir($this->aAdminOptions['sImageDirPath']) ) ? dirname(__FILE__) . '/images/' : $this->aAdminOptions['sImageDirPath'];
				$this->sImageThumbnailDirPath = ( empty($this->aAdminOptions['sImageThumbnailDirPath']) || !is_dir($this->aAdminOptions['sImageThumbnailDirPath']) ) ? dirname(__FILE__) . '/images/thumbs/' : $this->aAdminOptions['sImageThumbnailDirPath'];
				$this->sImageCacheDir = ( empty($this->aAdminOptions['sImageCacheDir']) || !is_dir($this->aAdminOptions['sImageCacheDir']) ) ? dirname(__FILE__) . '/php/phpThumb/cache/' : $this->aAdminOptions['sImageCacheDir'];

				$this->sImageDirUrl = ( empty($this->aAdminOptions['sImageDirUrl']) ) ? get_bloginfo('wpurl') . '/wp-content/plugins/auto-post-images-api/images/' : $this->aAdminOptions['sImageDirUrl'];
				$this->sImageThumbnailDirUrl = ( empty($this->aAdminOptions['sImageThumbnailDirUrl']) ) ? get_bloginfo('wpurl') . '/wp-content/plugins/auto-post-images-api/images/thumbs/' : $this->aAdminOptions['sImageThumbnailDirUrl'];

				//$this->sImageDirPath = dirname(__FILE__) . '/images/';
				//$this->sImageThumbnailDirPath = dirname(__FILE__) . '/images/thumbs/';

				//$this->sImageDirUrl = get_bloginfo('wpurl') . '/wp-content/plugins/auto-post-images-api/images/';
				//$this->sImageThumbnailDirUrl = get_bloginfo('wpurl') . '/wp-content/plugins/auto-post-images-api/images/thumbs/';

				$this->sDefaultImageUrl = $this->sImageDirUrl . $this->sDefaultImageName;

				if ($this->aAdminOptions['bOptmizeImagesForSearch'] == 'YES') {

					$this->sRegEx = '^' . $this->sImageSEOPrefix . '__POSTID___'; //[^\n]*\.[^\n]+$';

				} else {

					$this->sRegEx = $this->aAdminOptions['sRegEx'];
				}

				//echo '<pre>'.print_r($this, TRUE).'</pre>';
			}

			/**
			* Calls the getAdminOptions method
			*/
			function init () {

				$this->getAdminOptions();
			}

			/**
			* Gets the plugin settings from the database and initializes the plugin settings
			*
			* @return array The plugins setting
			*/
			function getAdminOptions () {

				$mAdminOptions = get_option($this->sAdminOptionsName);

				//echo '<pre>'.print_r($mAdminOptions, TRUE).'</pre>';

				if( !empty($mAdminOptions) ) {

					foreach( $mAdminOptions as $sKey => $mOption ) {

						$this->aAdminOptions[$sKey] = $mOption;
					}
				}

				update_option($this->sAdminOptionsName, $this->aAdminOptions);

				//echo '<pre>'.print_r($this->aAdminOptions, TRUE).'</pre>';

				return $this->aAdminOptions;
			}

			/**
			* The meat of the plugin. Searches for images for a blog post and inserts the image into the blog posts content
			*
			* @param string $sContent The content of the blog post
			* @return string The content of the blog post with the image code
			*/
			function showImagesByPostId ($sContent) {

				// If it is not a post then return the contents unmodified
				//
				if(is_page()) {

					return $sContent;
				}

				global $post;
				$this->iPostId = $post->ID;
				$sHtml = '';
				$bUseThumbnails = ( isset($this->aAdminOptions['bUseThumbnails']) ) ? $this->aAdminOptions['bUseThumbnails'] : FALSE;
				$bUsingDefaultImage = FALSE;

				if( !is_numeric($this->iPostId) ) {

					$this->iPostId = FALSE;
				}

				//
				// If SEO image optimization is turned ON then check the image name and rename if required
				//
				if ($this->aAdminOptions['bOptmizeImagesForSearch'] == 'YES') {

					$this->renameImagesForSEO();
				}

				$aImageFiles = $this->getImagesForThisPost($this->iPostId);

				$aImageUrls = array();

				//echo '<pre>'.print_r($aImageFiles, TRUE).'</pre>';

				foreach($aImageFiles as $sKey => $sImageName) {

					$sImageDirPath = $this->sImageDirPath . $sImageName;

					if( !is_file($sImageDirPath) ) {

						unset($aImageFiles[$sKey]);
						continue;
					}

					$aImageUrls[$sImageName] = $this->sImageDirUrl . $sImageName;
					$aImageFiles[$sImageName] = $sImageName;
					unset($aImageFiles[$sKey]);
				}

				// If no images were found for the post and the user wants to display default images
				//  then add the default image to the list of images to display
				//
				// Else if the user does not want to display default images then return the post contents unchanged
				//
				if( empty($aImageFiles) && $this->aAdminOptions['bDisplayDefaultImage'] == 'YES') {

					$aImageFiles[$this->sDefaultImageName] = $this->sDefaultImageName;
					$aImageUrls[$this->sDefaultImageName] = $this->sDefaultImageUrl;
					$bUsingDefaultImage = TRUE;

				} else if( empty($aImageFiles) && $this->aAdminOptions['bDisplayDefaultImage'] == 'NO') {

					return $sContent;
				}

				$sHtml .= '<div class="kkautopostimage">';

				foreach($aImageUrls as $sImageName => $sImageUrl) {

					$sThumbnailUrl = $sImageUrl;
					$sThumbSearchName = 'Default';

					if ( $bUsingDefaultImage === FALSE ) {

						// Setup thumbnail image
						//
						if( $bUseThumbnails === 'YES' ) {

							$sThumbnailName = 'thumb_' . $sImageName;
							$sThumbnailPath = $this->sImageThumbnailDirPath . $sThumbnailName;
							$sImageFilePath = $this->sImageDirPath . $sImageName;
							$sThumbnailUrl = $this->sImageThumbnailDirUrl . $sThumbnailName;

							if( FALSE === is_file($sThumbnailPath) ) {

								//
								// Create the thumbnail first
								//

								$oThumbs = new ThumbCreator();

								$bStatus = $oThumbs->createThumbnail($this->sImageDirPath, $sImageFilePath, $sThumbnailPath);

								if( $bStatus === FALSE ) {

									$sThumbnailUrl = $sImageUrl;
								}
							}
						}
					}

					$sThumbSearchName = $post->post_name;
					$sThumbSearchTags = str_replace('-', ' ', $sThumbSearchName);

					$sHtml .= "<a href=\"{$sImageUrl}\"  rel=\"ibox\" title=\"&nbsp;\"><img src=\"{$sThumbnailUrl}\" alt=\"{$sThumbSearchTags}\" title=\"Click to enlarge\" /></a><br />";
				}

				$sHtml .= '</div>';

				return $sHtml . $sContent;
			}

			/**
			* Hooked into 'wp_head' and inserts the css <link> tag into the pages <head>
			*/
			function includeCSS () {

				echo '<link type="text/css" rel="stylesheet" href="' . get_bloginfo('wpurl') . '/wp-content/plugins/auto-post-images-api/css/kkimageinpost.css" />' . "\n";
			}

			/**
			* Hooked into 'wp_head' and inserts the script <script> tag into the pages <head>
			*/
			function includeJS () {

				echo '<script type="text/javascript" src="' . get_bloginfo('wpurl') . '/wp-content/plugins/auto-post-images-api/js/ibox.js"></script>' . "\n";
				echo '<script type="text/javascript">iBox.setPath("js/");</script>' . "\n";
			}

			/**
			* Searches the /wp-content/plugins/auto-post-images-api/images/ folder for images for the given blog post ID and returns the filename
			*
			* @param int $iPostId The ID of the blog POST
			* @return array List of image file names
			*/
			function getImagesForThisPost($iPostId, $sRegEx = FALSE) {

				if(!is_numeric($iPostId)) {

					return $aEmpty = array();
				}

				if($sRegEx === FALSE) {

					$sRegEx = $this->sRegEx;
				}

				$oFileSys = new Filesystem();
				$sPattern = str_replace('__POSTID__', $iPostId, $sRegEx);

				$aImages = $oFileSys->readDir($this->sImageDirPath, $sPattern);

				//echo '<p>Pattern ==', $this->sImageDirPath, '==<br />==', $sPattern, '==</p>';
				//echo '<pre>', print_r($aImages, TRUE), '</pre>';

				return $aImages;
			}

			/**
			* Hooked into 'admin_menu' sets-up the plugins setting page handles the settings update
			*/
			function printAdminPage () {

				$aAdminOptions = $this->getAdminOptions();

				$aAdminOptions['sImageDirPath'] = $this->sImageDirPath;
				$aAdminOptions['sImageThumbnailDirPath'] = $this->sImageThumbnailDirPath;
				$aAdminOptions['sImageDirUrl'] = $this->sImageDirUrl;
				$aAdminOptions['sImageThumbnailDirUrl'] = $this->sImageThumbnailDirUrl;
				$aAdminOptions['sImageCacheDir'] = $this->sImageCacheDir;

				if (isset($_POST['updateAutoPostImagesSettings'])) {

					//echo '<pre>'.print_r($_POST, TRUE).'</pre>';

					if (isset($_POST['AutoPostImagesDisplayDefaultImages'])) {

						$aAdminOptions['bDisplayDefaultImage'] = ( $_POST['AutoPostImagesDisplayDefaultImages'] == 'YES' ) ? 'YES' : 'NO';
					}

					if (isset($_POST['AutoPostImagesUseThumbnails'])) {

						$aAdminOptions['bUseThumbnails'] = ( $_POST['AutoPostImagesUseThumbnails'] == 'YES' ) ? 'YES' : 'NO';
					}

					if (isset($_POST['AutoPostImagesOptmizeImagesForSearch'])) {

						$aAdminOptions['bOptmizeImagesForSearch'] = ( $_POST['AutoPostImagesOptmizeImagesForSearch'] == 'YES' ) ? 'YES' : 'NO';
					}

					if (isset($_POST['AutoPostImagesImgDir'])) {

						$aAdminOptions['sImageDirPath'] = ( !empty($_POST['AutoPostImagesImgDir']) && is_dir($_POST['AutoPostImagesImgDir']) ) ? $_POST['AutoPostImagesImgDir'] : $aAdminOptions['sImageDirPath'];
					}

					if (isset($_POST['AutoPostImagesThumbDir'])) {

						$aAdminOptions['sImageThumbnailDirPath'] = ( !empty($_POST['AutoPostImagesThumbDir']) && is_dir($_POST['AutoPostImagesThumbDir']) ) ? $_POST['AutoPostImagesThumbDir'] : $aAdminOptions['sImageThumbnailDirPath'];
					}

					if (isset($_POST['AutoPostImagesImgUrl'])) {

						$aAdminOptions['sImageDirUrl'] = ( !empty($_POST['AutoPostImagesImgUrl']) ) ? $_POST['AutoPostImagesImgUrl'] : $aAdminOptions['sImageDirUrl'];
					}

					if (isset($_POST['AutoPostImagesThumbUrl'])) {

						$aAdminOptions['sImageThumbnailDirUrl'] = ( !empty($_POST['AutoPostImagesThumbUrl']) ) ? $_POST['AutoPostImagesThumbUrl'] : $aAdminOptions['sImageThumbnailDirUrl'];
					}

					if (isset($_POST['AutoPostImagesRegEx'])) {

						$aAdminOptions['sRegEx'] = ( !empty($_POST['AutoPostImagesRegEx']) && strstr($_POST['AutoPostImagesRegEx'], '__POSTID__') ) ? str_replace('\\\\', '\\', trim($_POST['AutoPostImagesRegEx'])) : $aAdminOptions['sRegEx'];
					}

					if (isset($_POST['AutoPostImagesCacheDir'])) {

						$aAdminOptions['sImageCacheDir'] = ( !empty($_POST['AutoPostImagesCacheDir']) ) ? $_POST['AutoPostImagesCacheDir'] : $aAdminOptions['sImageCacheDir'];
					}

					if ( !ereg("__POSTID__", $aAdminOptions['sRegEx']) ) {

						$aAdminOptions['sRegEx'] = $this->sDefaultRegEx;
					}

					if ( !ereg("/$", $aAdminOptions['sImageDirPath']) ) {

						$aAdminOptions['sImageDirPath'] = $aAdminOptions['sImageDirPath'] . '/';
					}

					if ( !ereg("/$", $aAdminOptions['sImageThumbnailDirPath']) ) {

						$aAdminOptions['sImageThumbnailDirPath'] = $aAdminOptions['sImageThumbnailDirPath'] . '/';
					}

					if ( !ereg("/$", $aAdminOptions['sImageDirUrl']) ) {

						$aAdminOptions['sImageDirUrl'] = $aAdminOptions['sImageDirUrl'] . '/';
					}

					if ( !ereg("/$", $aAdminOptions['sImageThumbnailDirUrl']) ) {

						$aAdminOptions['sImageThumbnailDirUrl'] = $aAdminOptions['sImageThumbnailDirUrl'] . '/';
					}

					if ( !ereg("/$", $aAdminOptions['sImageCacheDir']) ) {

						$aAdminOptions['sImageCacheDir'] = $aAdminOptions['sImageCacheDir'] . '/';
					}

					update_option($this->sAdminOptionsName, $aAdminOptions);

					echo '<div class="updated"><p><strong>' . __("Settings Updated.", "KKAutoPostImages") . '</strong></p></div>';
				}

				$sRequestUri = $_SERVER["REQUEST_URI"];

				$sUpdateAutoPostImagesSubmitButton = __('Update Settings', 'KKAutoPostImages');

				//
				// Create radio buttons for DisplayDefaultImage admin option
				//
				$sDisplayDefaultImageYesRadio = __(' checked="checked" ', 'KKAutoPostImages');
				$sDisplayDefaultImageNoRadio = '';

				if ( $aAdminOptions['bDisplayDefaultImage'] == 'YES' ) {

					$sDisplayDefaultImageYesRadio = __(' checked="checked" ', 'KKAutoPostImages');
					$sDisplayDefaultImageNoRadio = '';

				} else {

					$sDisplayDefaultImageYesRadio = '';
					$sDisplayDefaultImageNoRadio = __(' checked="checked" ', 'KKAutoPostImages');
				}

				//
				// Create radio buttons for UseThumbnails admin option
				//
				$sUseThumbnailsYesRadio = __(' checked="checked" ', 'KKAutoPostImages');
				$sUseThumbnailsNoRadio = '';

				if ( $aAdminOptions['bUseThumbnails'] == 'YES' ) {

					$sUseThumbnailsYesRadio = __(' checked="checked" ', 'KKAutoPostImages');
					$sUseThumbnailsNoRadio = '';

				} else {

					$sUseThumbnailsYesRadio = '';
					$sUseThumbnailsNoRadio = __(' checked="checked" ', 'KKAutoPostImages');
				}

				//
				// Create radio buttons for OptmizeImagesForSearch admin option
				//
				$sOptmizeImagesForSearchYesRadio = __(' checked="checked" ', 'KKAutoPostImages');
				$sOptmizeImagesForSearchNoRadio = '';

				if ( $aAdminOptions['bOptmizeImagesForSearch'] == 'YES' ) {

					$sOptmizeImagesForSearchYesRadio = __(' checked="checked" ', 'KKAutoPostImages');
					$sOptmizeImagesForSearchNoRadio = '';

				} else {

					$sOptmizeImagesForSearchYesRadio = '';
					$sOptmizeImagesForSearchNoRadio = __(' checked="checked" ', 'KKAutoPostImages');
				}

				echo "
						<div class=\"wrap\">

							<form method=\"post\" action=\"{$sRequestUri}\">

								<h2>Auto Post Images (API) Settings</h2>

								<h3>Display default image if not image is found?</h3>

								<p>
									<input type=\"radio\" id=\"AutoPostImagesDisplayDefaultImages_yes\" name=\"AutoPostImagesDisplayDefaultImages\" value=\"YES\" {$sDisplayDefaultImageYesRadio} /> <label for=\"AutoPostImagesDisplayDefaultImages_yes\">Yes</label>
									<input type=\"radio\" id=\"AutoPostImagesDisplayDefaultImages_no\" name=\"AutoPostImagesDisplayDefaultImages\" value=\"NO\" {$sDisplayDefaultImageNoRadio} /> <label for=\"AutoPostImagesDisplayDefaultImages_no\">No</label>
								</p>

								<p>Selecting &quot;No&quot; will hide the default &quot;Image coming soon&quot; image if no images are found for the post.</p>

								<h3>Use thumbnails to link to full size images?</h3>

								<p>
									<input type=\"radio\" id=\"AutoPostImagesUseThumbnails_yes\" name=\"AutoPostImagesUseThumbnails\" value=\"YES\" {$sUseThumbnailsYesRadio} /> <label for=\"AutoPostImagesUseThumbnails_yes\">Yes</label>
									<input type=\"radio\" id=\"AutoPostImagesUseThumbnails_no\" name=\"AutoPostImagesUseThumbnails\" value=\"NO\" {$sUseThumbnailsNoRadio} /> <label for=\"AutoPostImagesUseThumbnails_no\">No</label>
								</p>

								<p>Selecting &quot;Yes&quot; will use thumbnail images in the post to link to full size images.</p>

								<h3>Image search Regular Expression?</h3>

								<p>
									<input type=\"text\" size=\"75\" id=\"AutoPostImagesRegEx\" name=\"AutoPostImagesRegEx\" value=\"$aAdminOptions[sRegEx]\" />
								</p>

								<p>
									Regular expression to use when searching for images associated with a post. Must have __POSTID__ somewhere in the expression which will be replaced with the actual post id before searching.
								</p>

								<p>
									<strong>Note: </strong>If <em>Rename images for SEO</em> (below) is enabled then images uploaded must still be named according to the regular expression specified here. The plugin will automatically rename images for SEO.
								</p>

								<h3>Rename images for SEO?</h3>

								<p>
									<input type=\"radio\" id=\"AutoPostImagesOptmizeImagesForSearch_yes\" name=\"AutoPostImagesOptmizeImagesForSearch\" value=\"YES\" {$sOptmizeImagesForSearchYesRadio} onClick=\"javascript:alert('Ensure that images uploaded are named according to the regular expression specified in Image search Regular Expression (above). The plugin will automatically rename images for SEO.')\" /> <label for=\"AutoPostImagesOptmizeImagesForSearch_yes\">Yes</label>
									<input type=\"radio\" id=\"AutoPostImagesOptmizeImagesForSearch_no\" name=\"AutoPostImagesOptmizeImagesForSearch\" value=\"NO\" {$sOptmizeImagesForSearchNoRadio} /> <label for=\"AutoPostImagesOptmizeImagesForSearch_no\">No</label>
								</p>

								<p>Selecting &quot;Yes&quot; will use rename the images using the POST title so that the images names are optimized for search.</p>

								<p>
									<strong>Note: </strong>Ensure that images uploaded are named according to the regular expression specified in <em>Image search Regular Expression</em> (above). The plugin will automatically rename images for SEO.
								</p>

								<h3>Image directory?</h3>

								<p>
									<input type=\"text\" size=\"75\" id=\"AutoPostImagesImgDir\" name=\"AutoPostImagesImgDir\" value=\"$aAdminOptions[sImageDirPath]\" />
								</p>

								<h3>Thumbnail directory?</h3>

								<p>
									<input type=\"text\" size=\"75\" id=\"AutoPostImagesThumbDir\" name=\"AutoPostImagesThumbDir\" value=\"$aAdminOptions[sImageThumbnailDirPath]\" />
								</p>

								<h3>Image directory URL?</h3>

								<p>
									<input type=\"text\" size=\"75\" id=\"AutoPostImagesImgUrl\" name=\"AutoPostImagesImgUrl\" value=\"$aAdminOptions[sImageDirUrl]\" />
								</p>

								<h3>Thumbnail directory URL?</h3>

								<p>
									<input type=\"text\" size=\"75\" id=\"AutoPostImagesThumbUrl\" name=\"AutoPostImagesThumbUrl\" value=\"$aAdminOptions[sImageThumbnailDirUrl]\" />
								</p>

								<h3>Cache directory? (Used by the thumbnail creator)</h3>

								<p>
									<input type=\"text\" size=\"75\" id=\"AutoPostImagesCacheDir\" name=\"AutoPostImagesCacheDir\" value=\"$aAdminOptions[sImageCacheDir]\" />
								</p>

								<div class=\"submit\">
									<input type=\"submit\" name=\"updateAutoPostImagesSettings\" value=\"{$sUpdateAutoPostImagesSubmitButton}\" />
								</div>
							</form>
						</div>
				";
			}

			function renameImagesForSEO() {

				global $post;

				$sThumbSearchName = $post->post_name;
				$sThumbSearchTags = str_replace('-', ' ', $sThumbSearchName);
				$iImageSeoCount = 0;

				//
				// If SEO image optimization is turned ON then check the image name and rename if required
				//

				$aImageFiles = $this->getImagesForThisPost($this->iPostId, $this->aAdminOptions['sRegEx']);

				foreach($aImageFiles as $sKey => $sImageName) {

					if ($this->aAdminOptions['bOptmizeImagesForSearch'] == 'YES') {

						if(!eregi($this->sImageSEOPattern, $sImageName)) {

							$sImageFilePath = $this->sImageDirPath . $sImageName;
							$sThumbImageFilePath = $this->sImageThumbnailDirPath . 'thumb_' . $sImageName;

							//echo '<p>Image - ', $sImageFilePath, '</p>';

							$sExtn = pathinfo($sImageFilePath, PATHINFO_EXTENSION);

							do {

								$sNewSeoImageName = $this->sImageSEOPrefix . $this->iPostId . '_' . $sThumbSearchName . '_' . $iImageSeoCount++  . '.' . $sExtn;
								$sNewSeoThumbImageName = 'thumb_' . $sNewSeoImageName;

								$sNewImageFilePath = $this->sImageDirPath . $sNewSeoImageName;
								$sNewThumbImageFilePath = $this->sImageThumbnailDirPath . $sNewSeoThumbImageName;

							} while (is_file($sNewSeoImageName) === TRUE);

							//echo "<p>rename {$sImageName} to {$sNewImageFilePath}</p>";
							//echo "<p>rename {$sThumbImageFilePath} to {$sNewThumbImageFilePath}</p>";

							//Rename the image file
							//
							if(is_file($sImageFilePath)) {

								rename($sImageFilePath, $sNewImageFilePath);
							}

							//Rename the thumbnail image file
							//
							if(is_file($sThumbImageFilePath)) {

								rename($sThumbImageFilePath, $sNewThumbImageFilePath);
							}
						}
					}
				}
			}

		} // End Class KKAutoPostImages

	} // End if


	//
	// Initialize the admin panel
	//
	if (!function_exists("AutoPostImages_AdminPageFunc")) {

		function AutoPostImages_AdminPageFunc () {

			global $oKKAutoPostImages;

			if ( !isset($oKKAutoPostImages) ) {

				return;
			}

			if ( function_exists('add_options_page') ) {

				add_options_page('Auto Post Images (API) Settings', 'Auto Post Images (API) Settings', 9, basename(__FILE__), array(&$oKKAutoPostImages, 'printAdminPage'));
			}
		}
	}

	/*
	 *
	 *    Initializing the class and hooking into wordpress
	 *
	 */

	if (class_exists("KKAutoPostImages")) {

		$oKKAutoPostImages = new KKAutoPostImages();
	}

	// Actions and Filters
	//
	if (isset($oKKAutoPostImages)) {

		//
		// Actions
		//

		// Admin screen for the Auto Post Images (API) plugin
		//
		add_action('admin_menu', 'AutoPostImages_AdminPageFunc');

		// Add the css and javascript files to the page <head>
		//
		add_action('wp_head', array(&$oKKAutoPostImages, 'includeCSS'), 1);
		add_action('wp_head', array(&$oKKAutoPostImages, 'includeJS'), 1);

		// Call the init function to initialize the admin options
		//
		add_action('activate_auto-post-images/auto-post-images.php',  array(&$oKKAutoPostImages, 'init'));

		//
		// Filters
		//

		// Add the image to the post content
		//
		add_filter('the_content', array(&$oKKAutoPostImages, 'showImagesByPostId'));
	}

?>